@@ -64,6 +64,21 @@ def RunShellCmd(command, start_dir = PROJECT_ROOT, env=None, verbose=False):
 # Check if the system is Windows
 def IsWindows(): return 'windows' == platform.system().lower()
 
+#
+# Set MACOSX_DEPLOYMENT_TARGET
+def SetupDarwin(osx):
+    if platform.system() != "Darwin":
+        return
+
+    # By default it will use the latest MacOS SDK available on the system.
+    if osx == 'latest':
+        return
+
+    # Currently the Vulkan SDK targets 10.15 as the minimum for MacOS support.
+    # If we need to we can raise the minimim like we did for C++17 support.
+    os.environ['MACOSX_DEPLOYMENT_TARGET'] = "10.15"
+    print(f"Targeting {os.environ['MACOSX_DEPLOYMENT_TARGET']} MacOS Deployment Target", flush=True)
+
 #
 # Run VVL scripts
 def CheckVVL(config):
@@ -71,21 +86,15 @@ def CheckVVL(config):
     vulkan_registry = ext_dir + "/Vulkan-Headers/registry"
     spirv_unified = ext_dir + "/SPIRV-Headers/include/spirv/unified1/"
 
-    # Scripts depend on modules within the Vulkan registry.
-    if "PYTHONPATH" in os.environ:
-        print(f"Using provided PYTHONPATH {os.environ['PYTHONPATH']}")
-    else:
-        os.environ['PYTHONPATH'] = vulkan_registry
-
     # Verify consistency of generated source code
     print("Check Generated Source Code Consistency")
-    gen_check_cmd = f'python3 scripts/generate_source.py --verify {vulkan_registry} {spirv_unified}'
+    gen_check_cmd = f'python scripts/generate_source.py --verify {vulkan_registry} {spirv_unified}'
     RunShellCmd(gen_check_cmd)
 
     print('Run vk_validation_stats.py')
     valid_usage_json = vulkan_registry + "/validusage.json"
     text_file = RepoRelative(f'{VVL_BUILD_DIR}/layers/vuid_coverage_database.txt')
-    gen_check_cmd = f'python3 scripts/vk_validation_stats.py {valid_usage_json} -text {text_file}'
+    gen_check_cmd = f'python scripts/vk_validation_stats.py {valid_usage_json} -text {text_file}'
     RunShellCmd(gen_check_cmd)
 
 #
@@ -128,11 +137,14 @@ def BuildLoader():
     LOADER_BUILD_DIR = RepoRelative("%s/Vulkan-Loader/%s" % (EXTERNAL_DIR_NAME, BUILD_DIR_NAME))
 
     print("Run CMake for Loader")
-    cmake_cmd = f'cmake -S {LOADER_DIR} -B {LOADER_BUILD_DIR} '
-    cmake_cmd += '-D UPDATE_DEPS=ON -D BUILD_TESTS=OFF -D CMAKE_BUILD_TYPE=Release'
-    # This enables better stack traces from leak sanitizer by using the loader feature which prevents unloading of libraries at shutdown.
+    cmake_cmd = f'cmake -S {LOADER_DIR} -B {LOADER_BUILD_DIR}'
+    cmake_cmd += ' -D UPDATE_DEPS=ON -D BUILD_TESTS=OFF -D CMAKE_BUILD_TYPE=Release'
+
+    # This enables better stack traces from tools like leak sanitizer by using the loader feature which prevents unloading of libraries at shutdown.
+    cmake_cmd += ' -D LOADER_DISABLE_DYNAMIC_LIBRARY_UNLOADING=ON'
+    
     if not IsWindows():
-        cmake_cmd += ' -D LOADER_ENABLE_ADDRESS_SANITIZER=ON -D LOADER_DISABLE_DYNAMIC_LIBRARY_UNLOADING=ON'
+        cmake_cmd += ' -D LOADER_ENABLE_ADDRESS_SANITIZER=ON'
     RunShellCmd(cmake_cmd)
 
     print("Build Loader")
@@ -154,13 +166,9 @@ def BuildMockICD():
 
     ICD_BUILD_DIR = RepoRelative("%s/Vulkan-Tools/%s" % (EXTERNAL_DIR_NAME,BUILD_DIR_NAME))
 
-    print("Running update_deps.py for ICD")
-    RunShellCmd(f'python3 scripts/update_deps.py --dir {EXTERNAL_DIR_NAME} --config release', VT_DIR)
-
     print("Run CMake for ICD")
     cmake_cmd = f'cmake -S {VT_DIR} -B {ICD_BUILD_DIR} -D CMAKE_BUILD_TYPE=Release '
-    cmake_cmd += '-DBUILD_CUBE=NO -DBUILD_VULKANINFO=NO -D INSTALL_ICD=ON '
-    cmake_cmd += f'-C {VT_DIR}/{EXTERNAL_DIR_NAME}/helper.cmake'
+    cmake_cmd += '-DBUILD_CUBE=NO -DBUILD_VULKANINFO=NO -D INSTALL_ICD=ON -D UPDATE_DEPS=ON'
     RunShellCmd(cmake_cmd)
 
     print("Build Mock ICD")
@@ -241,6 +249,9 @@ def GetArgParser():
     configs = ['release', 'debug']
     default_config = configs[0]
 
+    osx_choices = ['min', 'latest']
+    osx_default = osx_choices[1]
+
     parser = argparse.ArgumentParser()
     parser.add_argument(
         '-c', '--config', dest='configuration',
@@ -258,4 +269,8 @@ def GetArgParser():
     parser.add_argument(
         '--test', dest='test',
         action='store_true', help='Tests the layers')
+    parser.add_argument(
+        '--osx', dest='osx', action='store',
+        choices=osx_choices, default=osx_default,
+        help='Sets MACOSX_DEPLOYMENT_TARGET on Apple platforms.')
     return parser
